```
Usage: vcd catalog update [OPTIONS] <catalog-name>

Options:
  -n, --new_catalog_name [new-catalog-name]
  -d, --description [description]
  -h, --help                      Show this message and exit.

```
